import setuptools

setuptools.setup(
    name="deflatepybr",
    version="0.0.1",
    author="Thiago Eugênio",
    description="A simple package to deflate BR currency values using IPCA's historical yearly and monthly indexes",
    packages=["deflator"]
)